@@ -31,7 +31,7 @@ import textwrap
 import tokenize
 
 
-__version__ = '0.4.3'
+__version__ = '0.5'
 
 
 try:
@@ -207,12 +207,19 @@ def format_docstring(indentation, docstring,
                             subsequent_indent=indentation).strip()
 
 
-def indent_non_indented(line, indentation):
-    """Return indented line if it has no indentation."""
-    if line.lstrip() == line:
-        return indentation + line
-    else:
-        return line
+def reindent(text, indentation):
+    """Reindent text to match indentation."""
+    if '\t' not in indentation:
+        text = text.expandtabs(len(indentation))
+
+    # Ignore the first line, which is a special case.
+    split_lines = text.splitlines()
+    text = textwrap.dedent('\n'.join(split_lines[1:]))
+
+    return '\n'.join(
+        [indentation + split_lines[0].strip()] +
+        [(indentation + line).rstrip()
+         for line in text.splitlines()]).rstrip() + '\n'
 
 
 def is_probably_beginning_of_sentence(line):
@@ -238,23 +245,29 @@ def split_summary_and_description(contents):
     elif len(split) > 1 and is_probably_beginning_of_sentence(split[1]):
         # Symbol on second line probably is a description with a list.
         return (split[0], '\n'.join(split[1:]))
-    else:
-        # Break on first sentence.
-        for punctuation in '.?!:':
-            split = re.split('\\' + punctuation + r'\s',
-                             string=contents,
-                             maxsplit=1)
-            if len(split) == 2:
-                return (split[0].strip() + punctuation,
-                        split[1].strip())
 
-        # Break on first bullet-list-like text.
-        for token in ['    @',
-                      '    -',
-                      '    *']:
-            split = contents.split(token, 1)
-            if len(split) == 2:
-                return (split[0].strip(), (token + split[1]).strip())
+    if len(split) > 1:
+        for index, line in enumerate(split):
+            if not line.strip():
+                return ('\n'.join(split[:index]).strip(),
+                        '\n'.join(split[index:]).strip())
+
+    # Break on first sentence.
+    for punctuation in '.?!:':
+        split = re.split('\\' + punctuation + r'\s',
+                         string=contents,
+                         maxsplit=1)
+        if len(split) == 2:
+            return (split[0].strip() + punctuation,
+                    split[1].strip())
+
+    # Break on first bullet-list-like text.
+    for token in ['    @',
+                  '    -',
+                  '    *']:
+        split = contents.split(token, 1)
+        if len(split) == 2:
+            return (split[0].strip(), (token + split[1]).strip())
 
     return (split[0].strip(), '')
 
@@ -304,8 +317,7 @@ def wrap_description(text, indentation, wrap_length):
     if '>>>' in text:
         return text
 
-    text = '\n'.join([indent_non_indented(l, indentation).rstrip()
-                      for l in text.splitlines()])
+    text = reindent(text, indentation).rstrip()
 
     # Ignore possibly complicated cases.
     if (wrap_length <= 0 or
@@ -378,12 +390,14 @@ def main(argv, standard_out, standard_error):
                         help='make changes to files instead of printing diffs')
     parser.add_argument('-r', '--recursive', action='store_true',
                         help='drill down directories recursively')
-    parser.add_argument(
-        '--wrap-summaries', default=79, type=int, metavar='length',
-        help='wrap long summary lines at this length (default: %(default)s)')
-    parser.add_argument(
-        '--wrap-descriptions', default=0, type=int, metavar='length',
-        help='wrap descriptions at this length (default: %(default)s)')
+    parser.add_argument('--wrap-summaries', default=79, type=int,
+                        metavar='length',
+                        help='wrap long summary lines at this length '
+                             '(default: %(default)s)')
+    parser.add_argument('--wrap-descriptions', default=0, type=int,
+                        metavar='length',
+                        help='wrap descriptions at this length '
+                             '(default: %(default)s)')
     parser.add_argument('--no-blank', dest='post_description_blank',
                         action='store_false',
                         help='do not add blank line after description')
