@@ -64,16 +64,38 @@ Hello.
         self.assertEqual('''"""Hello.
 
     This should be indented but it is not. The
-    next line should be indented too. But
-    this is okay.
+    next line should be indented too. And
+    this too.
 
     """''',
                          docformatter.format_docstring('    ', '''
 """Hello.
 
-This should be indented but it is not. The
-next line should be indented too. But
-    this is okay.
+ This should be indented but it is not. The
+ next line should be indented too. And
+ this too.
+    """
+'''.strip()))
+
+    def test_format_docstring_with_too_much_indentation(self):
+        self.assertEqual('''"""Hello.
+
+    This should be dedented.
+
+    1. This too.
+    2. And this.
+    3. And this.
+
+    """''',
+                         docformatter.format_docstring('    ', '''
+"""Hello.
+
+        This should be dedented.
+
+        1. This too.
+        2. And this.
+        3. And this.
+
     """
 '''.strip()))
 
@@ -108,7 +130,7 @@ next line should be indented too. But
                                           description_wrap_length=72))
 
     def test_format_docstring_should_ignore_doctests_in_summary(self):
-        docstring = '''""" 
+        docstring = '''"""
     >>> 4
     4
 
@@ -300,7 +322,7 @@ is
 not."""
 ''',
             docformatter.format_code(
-            '''\
+                '''\
 #!/usr/env/bin python
 """This
 is
@@ -523,9 +545,7 @@ def foo():
         self.assertEqual(
             '''\
 def foo():
-    """Hello foo.
-
-    This is a docstring.
+    """Hello foo and this is a docstring.
 
     More stuff.
 
@@ -536,7 +556,7 @@ def foo():
 def foo():
     """
     Hello
-    foo. This is a docstring.
+    foo and this is a docstring.
 
     More stuff.
     """
@@ -546,9 +566,7 @@ def foo():
         self.assertEqual(
             '''\
 def foo():
-    """Hello foo.
-
-    This is a docstring.
+    """Hello foo and this is a docstring.
 
     More stuff.
 
@@ -559,7 +577,7 @@ def foo():
 def foo():
     """
     Hello
-    foo. This is a docstring.\t
+    foo and this is a docstring.\t
 
     More stuff.\t
     """
@@ -608,9 +626,7 @@ def foo():
         self.assertEqual(
             '''\
 def foo():
-    """Hello foo.
-
-    This is a docstring.
+    """Hello foo and this is a docstring.
 
     More stuff.
 
@@ -627,7 +643,7 @@ def foo():
 def foo():
     """
     Hello
-    foo. This is a docstring.
+    foo and this is a docstring.
 
     More stuff.
     """
@@ -693,25 +709,59 @@ def foo():
         self.assertEqual(('This is the first',
                           '@ one\n@ two'),
                          docformatter.split_summary_and_description(
-                         'This is the first\n@ one\n@ two'))
+                             'This is the first\n@ one\n@ two'))
 
     def test_split_summary_and_description_with_colon(self):
         self.assertEqual(('This is the first:',
                           'one\ntwo'),
                          docformatter.split_summary_and_description(
-                         'This is the first:\none\ntwo'))
+                             'This is the first:\none\ntwo'))
 
     def test_split_summary_and_description_with_exclamation(self):
         self.assertEqual(('This is the first!',
                           'one\ntwo'),
                          docformatter.split_summary_and_description(
-                         'This is the first!\none\ntwo'))
+                             'This is the first!\none\ntwo'))
 
     def test_split_summary_and_description_with_question_mark(self):
         self.assertEqual(('This is the first?',
                           'one\ntwo'),
                          docformatter.split_summary_and_description(
-                         'This is the first?\none\ntwo'))
+                             'This is the first?\none\ntwo'))
+
+    def test_split_summary_and_description_with_late__punctuation(self):
+        self.assertEqual(
+            ("""\
+Try this and this and this and this and this and this and this at
+    http://example.com/""",
+             """Parameters
+    ----------
+    email : string"""),
+            docformatter.split_summary_and_description('''\
+    Try this and this and this and this and this and this and this at
+    http://example.com/
+
+    Parameters
+    ----------
+    email : string
+'''))
+
+    def test_split_summary_and_description_without__punctuation(self):
+        self.assertEqual(
+            ("""\
+Try this and this and this and this and this and this and this at
+    this other line""",
+             """Parameters
+    ----------
+    email : string"""),
+            docformatter.split_summary_and_description('''\
+    Try this and this and this and this and this and this and this at
+    this other line
+
+    Parameters
+    ----------
+    email : string
+'''))
 
     def test_normalize_summary(self):
         self.assertEqual(
@@ -729,6 +779,38 @@ def foo():
             self.assertEqual('latin-1',
                              docformatter.detect_encoding(filename))
 
+    def test_reindent(self):
+        self.assertEqual(
+            """\
+    This should be dedented.
+
+    1. This too.
+    2. And this.
+""",
+            docformatter.reindent("""\
+                This should be dedented.
+
+                1. This too.
+                2. And this.
+            """, indentation='    ')
+        )
+
+    def test_reindent_should_expand_tabs_to_indentation(self):
+        self.assertEqual(
+            """\
+    This should be dedented.
+
+    1. This too.
+    2. And this.
+""",
+            docformatter.reindent("""\
+                This should be dedented.
+
+                1. This too.
+        \t\t2. And this.
+            """, indentation='    ')
+        )
+
 
 class TestSystem(unittest.TestCase):
 
